@@ -163,7 +163,7 @@ class AxlToolkit:
     """
 
     def __init__(self, username, password, server_ip, version='12.5', tls_verify=True, timeout=10,
-                 logging_enabled=False):
+                 logging_enabled=False, schema_folder_path=None):
         """
         Constructor - Create new instance
         """
@@ -175,7 +175,9 @@ class AxlToolkit:
         self.wsdl = None
         self.last_exception = None
 
-        schema_folder_path = os.path.dirname(__file__)
+        filedir = os.path.dirname(__file__)
+        if schema_folder_path is not None:
+            filedir = schema_folder_path
 
         self.cache = SqliteCache(path='/tmp/sqlite_axl_{0}.db'.format(server_ip), timeout=60)
 
@@ -2256,6 +2258,8 @@ class remotePhoneAccess:
         elif ConnectivityTest.status_code == 401:
             raise Exception(
                 'Unable to authenticate using the specified credentials and/or ip address. Please verify the information and/or reachability of the server.')
+        else:
+            raise Exception(ConnectivityTest.reason)
 
     def callmanager_setup(self):
         """
